@@ -9,7 +9,12 @@
     ## Author: Anders Gorst-Rasmussen
     
     mint <- min(x$times)
-    maxt <- x$times[max(which(x$event != 0))]
-    plot(stepfun(x$times, c(0, x$cumhaz)), main = "", xlab = "Time",
-         ylab="Cumulative baseline hazard", do.points = FALSE, xlim = c(mint, maxt), ...)
+    maxt <- x$times[order(x$times,decreasing=TRUE)[2]]#max(which(x$event != 0))]
+    plot.args <- list(x=stepfun(x$times, x$cumhaz),main="",xlab="Time",
+                    ylab="Cumulative baseline hazard",
+                    do.points = FALSE, xlim = c(mint, maxt))
+    new.args <- list(...)
+    if(length(new.args))
+      plot.args[names(new.args)] <- new.args
+    do.call("plot.stepfun",plot.args)
   }
